# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
TDataXtd module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_tdataxtd.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _TDataXtd
else:
    import _TDataXtd

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TDataXtd.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _TDataXtd.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TDataXtd.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TDataXtd.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _TDataXtd.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _TDataXtd.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _TDataXtd.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _TDataXtd.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _TDataXtd.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _TDataXtd.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TDataXtd.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _TDataXtd.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _TDataXtd.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TDataXtd.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TDataXtd.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TDataXtd.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _TDataXtd.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TDataXtd:
_TDataXtd.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _TDataXtd.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TDF
import OCC.Core.TCollection
import OCC.Core.TColStd
import OCC.Core.TDataStd
import OCC.Core.gp
import OCC.Core.TNaming
import OCC.Core.TopTools
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.Quantity
import OCC.Core.Poly
import OCC.Core.TColgp
import OCC.Core.TShort

from enum import IntEnum
from OCC.Core.Exception import *

TDataXtd_RADIUS = _TDataXtd.TDataXtd_RADIUS
TDataXtd_DIAMETER = _TDataXtd.TDataXtd_DIAMETER
TDataXtd_MINOR_RADIUS = _TDataXtd.TDataXtd_MINOR_RADIUS
TDataXtd_MAJOR_RADIUS = _TDataXtd.TDataXtd_MAJOR_RADIUS
TDataXtd_TANGENT = _TDataXtd.TDataXtd_TANGENT
TDataXtd_PARALLEL = _TDataXtd.TDataXtd_PARALLEL
TDataXtd_PERPENDICULAR = _TDataXtd.TDataXtd_PERPENDICULAR
TDataXtd_CONCENTRIC = _TDataXtd.TDataXtd_CONCENTRIC
TDataXtd_COINCIDENT = _TDataXtd.TDataXtd_COINCIDENT
TDataXtd_DISTANCE = _TDataXtd.TDataXtd_DISTANCE
TDataXtd_ANGLE = _TDataXtd.TDataXtd_ANGLE
TDataXtd_EQUAL_RADIUS = _TDataXtd.TDataXtd_EQUAL_RADIUS
TDataXtd_SYMMETRY = _TDataXtd.TDataXtd_SYMMETRY
TDataXtd_MIDPOINT = _TDataXtd.TDataXtd_MIDPOINT
TDataXtd_EQUAL_DISTANCE = _TDataXtd.TDataXtd_EQUAL_DISTANCE
TDataXtd_FIX = _TDataXtd.TDataXtd_FIX
TDataXtd_RIGID = _TDataXtd.TDataXtd_RIGID
TDataXtd_FROM = _TDataXtd.TDataXtd_FROM
TDataXtd_AXIS = _TDataXtd.TDataXtd_AXIS
TDataXtd_MATE = _TDataXtd.TDataXtd_MATE
TDataXtd_ALIGN_FACES = _TDataXtd.TDataXtd_ALIGN_FACES
TDataXtd_ALIGN_AXES = _TDataXtd.TDataXtd_ALIGN_AXES
TDataXtd_AXES_ANGLE = _TDataXtd.TDataXtd_AXES_ANGLE
TDataXtd_FACES_ANGLE = _TDataXtd.TDataXtd_FACES_ANGLE
TDataXtd_ROUND = _TDataXtd.TDataXtd_ROUND
TDataXtd_OFFSET = _TDataXtd.TDataXtd_OFFSET
TDataXtd_ANY_GEOM = _TDataXtd.TDataXtd_ANY_GEOM
TDataXtd_POINT = _TDataXtd.TDataXtd_POINT
TDataXtd_LINE = _TDataXtd.TDataXtd_LINE
TDataXtd_CIRCLE = _TDataXtd.TDataXtd_CIRCLE
TDataXtd_ELLIPSE = _TDataXtd.TDataXtd_ELLIPSE
TDataXtd_SPLINE = _TDataXtd.TDataXtd_SPLINE
TDataXtd_PLANE = _TDataXtd.TDataXtd_PLANE
TDataXtd_CYLINDER = _TDataXtd.TDataXtd_CYLINDER


class TDataXtd_ConstraintEnum(IntEnum):
	TDataXtd_RADIUS = 0
	TDataXtd_DIAMETER = 1
	TDataXtd_MINOR_RADIUS = 2
	TDataXtd_MAJOR_RADIUS = 3
	TDataXtd_TANGENT = 4
	TDataXtd_PARALLEL = 5
	TDataXtd_PERPENDICULAR = 6
	TDataXtd_CONCENTRIC = 7
	TDataXtd_COINCIDENT = 8
	TDataXtd_DISTANCE = 9
	TDataXtd_ANGLE = 10
	TDataXtd_EQUAL_RADIUS = 11
	TDataXtd_SYMMETRY = 12
	TDataXtd_MIDPOINT = 13
	TDataXtd_EQUAL_DISTANCE = 14
	TDataXtd_FIX = 15
	TDataXtd_RIGID = 16
	TDataXtd_FROM = 17
	TDataXtd_AXIS = 18
	TDataXtd_MATE = 19
	TDataXtd_ALIGN_FACES = 20
	TDataXtd_ALIGN_AXES = 21
	TDataXtd_AXES_ANGLE = 22
	TDataXtd_FACES_ANGLE = 23
	TDataXtd_ROUND = 24
	TDataXtd_OFFSET = 25
TDataXtd_RADIUS = TDataXtd_ConstraintEnum.TDataXtd_RADIUS
TDataXtd_DIAMETER = TDataXtd_ConstraintEnum.TDataXtd_DIAMETER
TDataXtd_MINOR_RADIUS = TDataXtd_ConstraintEnum.TDataXtd_MINOR_RADIUS
TDataXtd_MAJOR_RADIUS = TDataXtd_ConstraintEnum.TDataXtd_MAJOR_RADIUS
TDataXtd_TANGENT = TDataXtd_ConstraintEnum.TDataXtd_TANGENT
TDataXtd_PARALLEL = TDataXtd_ConstraintEnum.TDataXtd_PARALLEL
TDataXtd_PERPENDICULAR = TDataXtd_ConstraintEnum.TDataXtd_PERPENDICULAR
TDataXtd_CONCENTRIC = TDataXtd_ConstraintEnum.TDataXtd_CONCENTRIC
TDataXtd_COINCIDENT = TDataXtd_ConstraintEnum.TDataXtd_COINCIDENT
TDataXtd_DISTANCE = TDataXtd_ConstraintEnum.TDataXtd_DISTANCE
TDataXtd_ANGLE = TDataXtd_ConstraintEnum.TDataXtd_ANGLE
TDataXtd_EQUAL_RADIUS = TDataXtd_ConstraintEnum.TDataXtd_EQUAL_RADIUS
TDataXtd_SYMMETRY = TDataXtd_ConstraintEnum.TDataXtd_SYMMETRY
TDataXtd_MIDPOINT = TDataXtd_ConstraintEnum.TDataXtd_MIDPOINT
TDataXtd_EQUAL_DISTANCE = TDataXtd_ConstraintEnum.TDataXtd_EQUAL_DISTANCE
TDataXtd_FIX = TDataXtd_ConstraintEnum.TDataXtd_FIX
TDataXtd_RIGID = TDataXtd_ConstraintEnum.TDataXtd_RIGID
TDataXtd_FROM = TDataXtd_ConstraintEnum.TDataXtd_FROM
TDataXtd_AXIS = TDataXtd_ConstraintEnum.TDataXtd_AXIS
TDataXtd_MATE = TDataXtd_ConstraintEnum.TDataXtd_MATE
TDataXtd_ALIGN_FACES = TDataXtd_ConstraintEnum.TDataXtd_ALIGN_FACES
TDataXtd_ALIGN_AXES = TDataXtd_ConstraintEnum.TDataXtd_ALIGN_AXES
TDataXtd_AXES_ANGLE = TDataXtd_ConstraintEnum.TDataXtd_AXES_ANGLE
TDataXtd_FACES_ANGLE = TDataXtd_ConstraintEnum.TDataXtd_FACES_ANGLE
TDataXtd_ROUND = TDataXtd_ConstraintEnum.TDataXtd_ROUND
TDataXtd_OFFSET = TDataXtd_ConstraintEnum.TDataXtd_OFFSET

class TDataXtd_GeometryEnum(IntEnum):
	TDataXtd_ANY_GEOM = 0
	TDataXtd_POINT = 1
	TDataXtd_LINE = 2
	TDataXtd_CIRCLE = 3
	TDataXtd_ELLIPSE = 4
	TDataXtd_SPLINE = 5
	TDataXtd_PLANE = 6
	TDataXtd_CYLINDER = 7
TDataXtd_ANY_GEOM = TDataXtd_GeometryEnum.TDataXtd_ANY_GEOM
TDataXtd_POINT = TDataXtd_GeometryEnum.TDataXtd_POINT
TDataXtd_LINE = TDataXtd_GeometryEnum.TDataXtd_LINE
TDataXtd_CIRCLE = TDataXtd_GeometryEnum.TDataXtd_CIRCLE
TDataXtd_ELLIPSE = TDataXtd_GeometryEnum.TDataXtd_ELLIPSE
TDataXtd_SPLINE = TDataXtd_GeometryEnum.TDataXtd_SPLINE
TDataXtd_PLANE = TDataXtd_GeometryEnum.TDataXtd_PLANE
TDataXtd_CYLINDER = TDataXtd_GeometryEnum.TDataXtd_CYLINDER


def Handle_TDataXtd_Axis_Create() -> "opencascade::handle< TDataXtd_Axis >":
    return _TDataXtd.Handle_TDataXtd_Axis_Create()

def Handle_TDataXtd_Axis_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_Axis >":
    return _TDataXtd.Handle_TDataXtd_Axis_DownCast(t)

def Handle_TDataXtd_Axis_IsNull(t: "opencascade::handle< TDataXtd_Axis > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_Axis_IsNull(t)

def Handle_TDataXtd_Constraint_Create() -> "opencascade::handle< TDataXtd_Constraint >":
    return _TDataXtd.Handle_TDataXtd_Constraint_Create()

def Handle_TDataXtd_Constraint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_Constraint >":
    return _TDataXtd.Handle_TDataXtd_Constraint_DownCast(t)

def Handle_TDataXtd_Constraint_IsNull(t: "opencascade::handle< TDataXtd_Constraint > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_Constraint_IsNull(t)

def Handle_TDataXtd_Geometry_Create() -> "opencascade::handle< TDataXtd_Geometry >":
    return _TDataXtd.Handle_TDataXtd_Geometry_Create()

def Handle_TDataXtd_Geometry_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_Geometry >":
    return _TDataXtd.Handle_TDataXtd_Geometry_DownCast(t)

def Handle_TDataXtd_Geometry_IsNull(t: "opencascade::handle< TDataXtd_Geometry > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_Geometry_IsNull(t)

def Handle_TDataXtd_Pattern_Create() -> "opencascade::handle< TDataXtd_Pattern >":
    return _TDataXtd.Handle_TDataXtd_Pattern_Create()

def Handle_TDataXtd_Pattern_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_Pattern >":
    return _TDataXtd.Handle_TDataXtd_Pattern_DownCast(t)

def Handle_TDataXtd_Pattern_IsNull(t: "opencascade::handle< TDataXtd_Pattern > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_Pattern_IsNull(t)

def Handle_TDataXtd_Placement_Create() -> "opencascade::handle< TDataXtd_Placement >":
    return _TDataXtd.Handle_TDataXtd_Placement_Create()

def Handle_TDataXtd_Placement_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_Placement >":
    return _TDataXtd.Handle_TDataXtd_Placement_DownCast(t)

def Handle_TDataXtd_Placement_IsNull(t: "opencascade::handle< TDataXtd_Placement > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_Placement_IsNull(t)

def Handle_TDataXtd_Plane_Create() -> "opencascade::handle< TDataXtd_Plane >":
    return _TDataXtd.Handle_TDataXtd_Plane_Create()

def Handle_TDataXtd_Plane_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_Plane >":
    return _TDataXtd.Handle_TDataXtd_Plane_DownCast(t)

def Handle_TDataXtd_Plane_IsNull(t: "opencascade::handle< TDataXtd_Plane > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_Plane_IsNull(t)

def Handle_TDataXtd_Point_Create() -> "opencascade::handle< TDataXtd_Point >":
    return _TDataXtd.Handle_TDataXtd_Point_Create()

def Handle_TDataXtd_Point_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_Point >":
    return _TDataXtd.Handle_TDataXtd_Point_DownCast(t)

def Handle_TDataXtd_Point_IsNull(t: "opencascade::handle< TDataXtd_Point > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_Point_IsNull(t)

def Handle_TDataXtd_Position_Create() -> "opencascade::handle< TDataXtd_Position >":
    return _TDataXtd.Handle_TDataXtd_Position_Create()

def Handle_TDataXtd_Position_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_Position >":
    return _TDataXtd.Handle_TDataXtd_Position_DownCast(t)

def Handle_TDataXtd_Position_IsNull(t: "opencascade::handle< TDataXtd_Position > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_Position_IsNull(t)

def Handle_TDataXtd_Presentation_Create() -> "opencascade::handle< TDataXtd_Presentation >":
    return _TDataXtd.Handle_TDataXtd_Presentation_Create()

def Handle_TDataXtd_Presentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_Presentation >":
    return _TDataXtd.Handle_TDataXtd_Presentation_DownCast(t)

def Handle_TDataXtd_Presentation_IsNull(t: "opencascade::handle< TDataXtd_Presentation > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_Presentation_IsNull(t)

def Handle_TDataXtd_Shape_Create() -> "opencascade::handle< TDataXtd_Shape >":
    return _TDataXtd.Handle_TDataXtd_Shape_Create()

def Handle_TDataXtd_Shape_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_Shape >":
    return _TDataXtd.Handle_TDataXtd_Shape_DownCast(t)

def Handle_TDataXtd_Shape_IsNull(t: "opencascade::handle< TDataXtd_Shape > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_Shape_IsNull(t)

def Handle_TDataXtd_Triangulation_Create() -> "opencascade::handle< TDataXtd_Triangulation >":
    return _TDataXtd.Handle_TDataXtd_Triangulation_Create()

def Handle_TDataXtd_Triangulation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_Triangulation >":
    return _TDataXtd.Handle_TDataXtd_Triangulation_DownCast(t)

def Handle_TDataXtd_Triangulation_IsNull(t: "opencascade::handle< TDataXtd_Triangulation > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_Triangulation_IsNull(t)

def Handle_TDataXtd_PatternStd_Create() -> "opencascade::handle< TDataXtd_PatternStd >":
    return _TDataXtd.Handle_TDataXtd_PatternStd_Create()

def Handle_TDataXtd_PatternStd_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_PatternStd >":
    return _TDataXtd.Handle_TDataXtd_PatternStd_DownCast(t)

def Handle_TDataXtd_PatternStd_IsNull(t: "opencascade::handle< TDataXtd_PatternStd > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_PatternStd_IsNull(t)

def Handle_TDataXtd_HArray1OfTrsf_Create() -> "opencascade::handle< TDataXtd_HArray1OfTrsf >":
    return _TDataXtd.Handle_TDataXtd_HArray1OfTrsf_Create()

def Handle_TDataXtd_HArray1OfTrsf_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TDataXtd_HArray1OfTrsf >":
    return _TDataXtd.Handle_TDataXtd_HArray1OfTrsf_DownCast(t)

def Handle_TDataXtd_HArray1OfTrsf_IsNull(t: "opencascade::handle< TDataXtd_HArray1OfTrsf > const &") -> "bool":
    return _TDataXtd.Handle_TDataXtd_HArray1OfTrsf_IsNull(t)
class TDataXtd_Array1OfTrsf(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< gp_Trsf >::iterator":
        return _TDataXtd.TDataXtd_Array1OfTrsf_begin(self)

    def end(self) -> "NCollection_Array1< gp_Trsf >::iterator":
        return _TDataXtd.TDataXtd_Array1OfTrsf_end(self)

    def cbegin(self) -> "NCollection_Array1< gp_Trsf >::const_iterator":
        return _TDataXtd.TDataXtd_Array1OfTrsf_cbegin(self)

    def cend(self) -> "NCollection_Array1< gp_Trsf >::const_iterator":
        return _TDataXtd.TDataXtd_Array1OfTrsf_cend(self)

    def __init__(self, *args):
        _TDataXtd.TDataXtd_Array1OfTrsf_swiginit(self, _TDataXtd.new_TDataXtd_Array1OfTrsf(*args))

    def Init(self, theValue: "gp_Trsf") -> "void":
        return _TDataXtd.TDataXtd_Array1OfTrsf_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TDataXtd.TDataXtd_Array1OfTrsf_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TDataXtd.TDataXtd_Array1OfTrsf_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TDataXtd.TDataXtd_Array1OfTrsf_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _TDataXtd.TDataXtd_Array1OfTrsf_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TDataXtd.TDataXtd_Array1OfTrsf_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TDataXtd.TDataXtd_Array1OfTrsf_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _TDataXtd.TDataXtd_Array1OfTrsf_IsAllocated(self)

    def Assign(self, theOther: "TDataXtd_Array1OfTrsf") -> "NCollection_Array1< gp_Trsf > &":
        return _TDataXtd.TDataXtd_Array1OfTrsf_Assign(self, theOther)

    def Move(self, theOther: "TDataXtd_Array1OfTrsf") -> "NCollection_Array1< gp_Trsf > &":
        return _TDataXtd.TDataXtd_Array1OfTrsf_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< gp_Trsf > &":
        return _TDataXtd.TDataXtd_Array1OfTrsf_Set(self, *args)

    def First(self) -> "gp_Trsf const &":
        return _TDataXtd.TDataXtd_Array1OfTrsf_First(self)

    def ChangeFirst(self) -> "gp_Trsf &":
        return _TDataXtd.TDataXtd_Array1OfTrsf_ChangeFirst(self)

    def Last(self) -> "gp_Trsf const &":
        return _TDataXtd.TDataXtd_Array1OfTrsf_Last(self)

    def ChangeLast(self) -> "gp_Trsf &":
        return _TDataXtd.TDataXtd_Array1OfTrsf_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "gp_Trsf const &":
        return _TDataXtd.TDataXtd_Array1OfTrsf_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "gp_Trsf &":
        return _TDataXtd.TDataXtd_Array1OfTrsf_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "gp_Trsf &":
        return _TDataXtd.TDataXtd_Array1OfTrsf___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "gp_Trsf") -> "void":
        return _TDataXtd.TDataXtd_Array1OfTrsf_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _TDataXtd.TDataXtd_Array1OfTrsf_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _TDataXtd.delete_TDataXtd_Array1OfTrsf

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register TDataXtd_Array1OfTrsf in _TDataXtd:
_TDataXtd.TDataXtd_Array1OfTrsf_swigregister(TDataXtd_Array1OfTrsf)

class tdataxtd(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def IDList(*args) -> "void":
        r"""
        Appends to <anidlist> the list of the attributes ids of this package. caution: <anidlist> is not cleared before use. print of tdataext enumeration =============================.

        Parameters
        ----------
        anIDList: TDF_IDList

        Returns
        -------
        None

        """
        return _TDataXtd.tdataxtd_IDList(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _TDataXtd.tdataxtd_swiginit(self, _TDataXtd.new_tdataxtd())
    __swig_destroy__ = _TDataXtd.delete_tdataxtd

# Register tdataxtd in _TDataXtd:
_TDataXtd.tdataxtd_swigregister(tdataxtd)

def tdataxtd_IDList(*args) -> "void":
    r"""
    Appends to <anidlist> the list of the attributes ids of this package. caution: <anidlist> is not cleared before use. print of tdataext enumeration =============================.

    Parameters
    ----------
    anIDList: TDF_IDList

    Returns
    -------
    None

    """
    return _TDataXtd.tdataxtd_IDList(*args)

class TDataXtd_Axis(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TDataXtd.TDataXtd_Axis_swiginit(self, _TDataXtd.new_TDataXtd_Axis(*args))

    def DumpToString(self) -> "std::string":
        r"""DumpToString(TDataXtd_Axis self) -> std::string"""
        return _TDataXtd.TDataXtd_Axis_DumpToString(self)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        Class methods ============= returns the guid for an axis.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Axis_GetID(*args)

    def ID(self, *args) -> "Standard_GUID const &":
        r"""
        No available documentation.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Axis_ID(self, *args)

    @staticmethod
    def Set(*args) -> "opencascade::handle< TDataXtd_Axis >":
        r"""
        Finds or creates an axis attribute defined by the label. in the case of a creation of an axis, a compatible named shape should already be associated with label. exceptions standard_nullobject if no compatible named shape is associated with the label.

        Parameters
        ----------
        label: TDF_Label

        Returns
        -------
        opencascade::handle<TDataXtd_Axis>
        Find, or create, an axis attribute and set <p> as generated in the associated namedshape. axis methods ============.

        Parameters
        ----------
        label: TDF_Label
        L: gp_Lin

        Returns
        -------
        opencascade::handle<TDataXtd_Axis>

        """
        return _TDataXtd.TDataXtd_Axis_Set(*args)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_Axis_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_Axis

# Register TDataXtd_Axis in _TDataXtd:
_TDataXtd.TDataXtd_Axis_swigregister(TDataXtd_Axis)

def TDataXtd_Axis_GetID(*args) -> "Standard_GUID const &":
    r"""
    Class methods ============= returns the guid for an axis.

    Returns
    -------
    Standard_GUID

    """
    return _TDataXtd.TDataXtd_Axis_GetID(*args)

def TDataXtd_Axis_Set(*args) -> "opencascade::handle< TDataXtd_Axis >":
    r"""
    Finds or creates an axis attribute defined by the label. in the case of a creation of an axis, a compatible named shape should already be associated with label. exceptions standard_nullobject if no compatible named shape is associated with the label.

    Parameters
    ----------
    label: TDF_Label

    Returns
    -------
    opencascade::handle<TDataXtd_Axis>
    Find, or create, an axis attribute and set <p> as generated in the associated namedshape. axis methods ============.

    Parameters
    ----------
    label: TDF_Label
    L: gp_Lin

    Returns
    -------
    opencascade::handle<TDataXtd_Axis>

    """
    return _TDataXtd.TDataXtd_Axis_Set(*args)

class TDataXtd_Constraint(OCC.Core.TDF.TDF_Attribute):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TDataXtd.TDataXtd_Constraint_swiginit(self, _TDataXtd.new_TDataXtd_Constraint(*args))

    def ClearGeometries(self, *args) -> "void":
        r"""
        Removes the geometries involved in the constraint or dimension from the array of topological attributes where they are stored.

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Constraint_ClearGeometries(self, *args)

    @staticmethod
    def CollectChildConstraints(*args) -> "void":
        r"""
        Collects constraints on childs for label <alabel>.

        Parameters
        ----------
        aLabel: TDF_Label
        TheList: TDF_LabelList

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Constraint_CollectChildConstraints(*args)

    def DumpToString(self) -> "std::string":
        r"""DumpToString(TDataXtd_Constraint self) -> std::string"""
        return _TDataXtd.TDataXtd_Constraint_DumpToString(self)

    def GetGeometry(self, *args) -> "opencascade::handle< TNaming_NamedShape >":
        r"""
        Returns the integer index index used to access the array of the constraint or stored geometries of a dimension index has a value between 1 and 4. methods to write constraint fields (use builder) ==================================.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<TNaming_NamedShape>

        """
        return _TDataXtd.TDataXtd_Constraint_GetGeometry(self, *args)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        Returns the guid for constraints.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Constraint_GetID(*args)

    def GetPlane(self, *args) -> "opencascade::handle< TNaming_NamedShape > const &":
        r"""
        Returns the topological attribute of the plane used for planar - i.e., 2d - constraints. this plane is attached to another label. if the constraint is not planar, in other words, 3d, this function will return a null handle.

        Returns
        -------
        opencascade::handle<TNaming_NamedShape>

        """
        return _TDataXtd.TDataXtd_Constraint_GetPlane(self, *args)

    def GetType(self, *args) -> "TDataXtd_ConstraintEnum":
        r"""
        Returns the type of constraint. this will be an element of the tdataxtd_constraintenum enumeration.

        Returns
        -------
        TDataXtd_ConstraintEnum

        """
        return _TDataXtd.TDataXtd_Constraint_GetType(self, *args)

    def GetValue(self, *args) -> "opencascade::handle< TDataStd_Real > const &":
        r"""
        Returns the value of a dimension. this value is a reference to a tdatastd_real attribute. if the attribute is not a dimension, this value will be 0. use isdimension to test this condition.

        Returns
        -------
        opencascade::handle<TDataStd_Real>

        """
        return _TDataXtd.TDataXtd_Constraint_GetValue(self, *args)

    def Inverted(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        status: bool

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Constraint_Inverted(self, *args)

    def IsDimension(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this constraint attribute is a dimension, and therefore has a value.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Constraint_IsDimension(self, *args)

    def IsPlanar(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this constraint attribute is two-dimensional.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Constraint_IsPlanar(self, *args)

    def NbGeometries(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of geometry attributes in this constraint attribute. this number will be between 1 and 4.

        Returns
        -------
        int

        """
        return _TDataXtd.TDataXtd_Constraint_NbGeometries(self, *args)

    def Reversed(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        status: bool

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Constraint_Reversed(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Finds or creates the 2d constraint attribute defined by the planar topological attribute plane and the label label. constraint methods ==================.

        Parameters
        ----------
        label: TDF_Label

        Returns
        -------
        opencascade::handle<TDataXtd_Constraint>
        Finds or creates the constraint attribute defined by the topological attribute g1 and the constraint type type.

        Parameters
        ----------
        type: TDataXtd_ConstraintEnum
        G1: TNaming_NamedShape

        Returns
        -------
        None
        Finds or creates the constraint attribute defined by the topological attributes g1 and g2, and by the constraint type type.

        Parameters
        ----------
        type: TDataXtd_ConstraintEnum
        G1: TNaming_NamedShape
        G2: TNaming_NamedShape

        Returns
        -------
        None
        Finds or creates the constraint attribute defined by the topological attributes g1, g2 and g3, and by the constraint type type.

        Parameters
        ----------
        type: TDataXtd_ConstraintEnum
        G1: TNaming_NamedShape
        G2: TNaming_NamedShape
        G3: TNaming_NamedShape

        Returns
        -------
        None
        Finds or creates the constraint attribute defined by the topological attributes g1, g2, g3 and g4, and by the constraint type type. methods to read constraint fields =================================.

        Parameters
        ----------
        type: TDataXtd_ConstraintEnum
        G1: TNaming_NamedShape
        G2: TNaming_NamedShape
        G3: TNaming_NamedShape
        G4: TNaming_NamedShape

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Constraint_Set(self, *args)

    def SetGeometry(self, *args) -> "void":
        r"""
        Finds or creates the underlying geometry of the constraint defined by the topological attribute g and the integer index index.

        Parameters
        ----------
        Index: int
        G: TNaming_NamedShape

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Constraint_SetGeometry(self, *args)

    def SetPlane(self, *args) -> "void":
        r"""
        Finds or creates the plane of the 2d constraint attribute, defined by the planar topological attribute plane.

        Parameters
        ----------
        plane: TNaming_NamedShape

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Constraint_SetPlane(self, *args)

    def SetType(self, *args) -> "void":
        r"""
        Finds or creates the type of constraint ctr.

        Parameters
        ----------
        CTR: TDataXtd_ConstraintEnum

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Constraint_SetType(self, *args)

    def SetValue(self, *args) -> "void":
        r"""
        Finds or creates the real number value v of the dimension constraint attribute.

        Parameters
        ----------
        V: TDataStd_Real

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Constraint_SetValue(self, *args)

    def Verified(self, *args) -> "void":
        r"""
        Returns true if this constraint attribute is valid. by default, true is returned. when the value of a dimension is changed or when a geometry is moved, false is returned until the solver sets it back to true.

        Returns
        -------
        bool
        Returns true if this constraint attribute defined by status is valid. by default, true is returned. when the value of a dimension is changed or when a geometry is moved, false is returned until the solver sets it back to true. if status is false, verified is set to false.

        Parameters
        ----------
        status: bool

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Constraint_Verified(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_Constraint_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_Constraint

# Register TDataXtd_Constraint in _TDataXtd:
_TDataXtd.TDataXtd_Constraint_swigregister(TDataXtd_Constraint)

def TDataXtd_Constraint_CollectChildConstraints(*args) -> "void":
    r"""
    Collects constraints on childs for label <alabel>.

    Parameters
    ----------
    aLabel: TDF_Label
    TheList: TDF_LabelList

    Returns
    -------
    None

    """
    return _TDataXtd.TDataXtd_Constraint_CollectChildConstraints(*args)

def TDataXtd_Constraint_GetID(*args) -> "Standard_GUID const &":
    r"""
    Returns the guid for constraints.

    Returns
    -------
    Standard_GUID

    """
    return _TDataXtd.TDataXtd_Constraint_GetID(*args)

class TDataXtd_Geometry(OCC.Core.TDF.TDF_Attribute):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        This and the next methods are used to retrieve underlying geometry of the namedshape, even if noone geometry attribute is associated . if not found or not compliant geometry return false.

        Returns
        -------
        None

        """
        _TDataXtd.TDataXtd_Geometry_swiginit(self, _TDataXtd.new_TDataXtd_Geometry(*args))

    @staticmethod
    def Axis(*args) -> "Standard_Boolean":
        r"""
        Returns the axis attribute defined by the label l and the axis g.

        Parameters
        ----------
        L: TDF_Label
        G: gp_Ax1

        Returns
        -------
        bool
        Returns the axis attribute defined by the topological attribute s and the axis g.

        Parameters
        ----------
        S: TNaming_NamedShape
        G: gp_Ax1

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Geometry_Axis(*args)

    @staticmethod
    def Circle(*args) -> "Standard_Boolean":
        r"""
        Returns the circle attribute defined by the label l and the circle g.

        Parameters
        ----------
        L: TDF_Label
        G: gp_Circ

        Returns
        -------
        bool
        Returns the circle attribute defined by the topological attribute s and the circle g.

        Parameters
        ----------
        S: TNaming_NamedShape
        G: gp_Circ

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Geometry_Circle(*args)

    @staticmethod
    def Cylinder(*args) -> "Standard_Boolean":
        r"""
        Returns the cylinder attribute defined by the label l and the cylinder g.

        Parameters
        ----------
        L: TDF_Label
        G: gp_Cylinder

        Returns
        -------
        bool
        Returns the cylinder attribute defined by the topological attribute s and the cylinder g.

        Parameters
        ----------
        S: TNaming_NamedShape
        G: gp_Cylinder

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Geometry_Cylinder(*args)

    def DumpToString(self) -> "std::string":
        r"""DumpToString(TDataXtd_Geometry self) -> std::string"""
        return _TDataXtd.TDataXtd_Geometry_DumpToString(self)

    @staticmethod
    def Ellipse(*args) -> "Standard_Boolean":
        r"""
        Returns the ellipse attribute defined by the label l and the ellipse g.

        Parameters
        ----------
        L: TDF_Label
        G: gp_Elips

        Returns
        -------
        bool
        Returns the ellipse attribute defined by the topological attribute s and the ellipse g.

        Parameters
        ----------
        S: TNaming_NamedShape
        G: gp_Elips

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Geometry_Ellipse(*args)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        Returns the guid for geometry attributes.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Geometry_GetID(*args)

    def GetType(self, *args) -> "TDataXtd_GeometryEnum":
        r"""
        Returns the type of geometric construction.

        Returns
        -------
        TDataXtd_GeometryEnum

        """
        return _TDataXtd.TDataXtd_Geometry_GetType(self, *args)

    @staticmethod
    def Line(*args) -> "Standard_Boolean":
        r"""
        Returns the line attribute defined by the label l and the line g.

        Parameters
        ----------
        L: TDF_Label
        G: gp_Lin

        Returns
        -------
        bool
        Returns the line attribute defined by the topological attribute s and the line g.

        Parameters
        ----------
        S: TNaming_NamedShape
        G: gp_Lin

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Geometry_Line(*args)

    @staticmethod
    def Plane(*args) -> "Standard_Boolean":
        r"""
        Returns the plane attribute defined by the label l and the plane g.

        Parameters
        ----------
        L: TDF_Label
        G: gp_Pln

        Returns
        -------
        bool
        Returns the plane attribute defined by the topological attribute s and the plane g.

        Parameters
        ----------
        S: TNaming_NamedShape
        G: gp_Pln

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Geometry_Plane(*args)

    @staticmethod
    def Point(*args) -> "Standard_Boolean":
        r"""
        Returns the point attribute defined by the label l and the point g.

        Parameters
        ----------
        L: TDF_Label
        G: gp_Pnt

        Returns
        -------
        bool
        Returns the point attribute defined by the topological attribute s and the point g.

        Parameters
        ----------
        S: TNaming_NamedShape
        G: gp_Pnt

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Geometry_Point(*args)

    @staticmethod
    def Set(*args) -> "opencascade::handle< TDataXtd_Geometry >":
        r"""
        Api class methods ================= finds, or creates, a geometry attribute defined by the label label. the default type of geometry is the value any_geom of the enumeration tdataxtd_geometryenum. to specify another value of this enumeration, use the function settype.

        Parameters
        ----------
        label: TDF_Label

        Returns
        -------
        opencascade::handle<TDataXtd_Geometry>

        """
        return _TDataXtd.TDataXtd_Geometry_Set(*args)

    def SetType(self, *args) -> "void":
        r"""
        Returns the type of geometric construction t of this attribute. t will be a value of the enumeration tdataxtd_geometryenum.

        Parameters
        ----------
        T: TDataXtd_GeometryEnum

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Geometry_SetType(self, *args)

    @staticmethod
    def Type(*args) -> "TDataXtd_GeometryEnum":
        r"""
        Returns the label l used to define the type of geometric construction for the geometry attribute.

        Parameters
        ----------
        L: TDF_Label

        Returns
        -------
        TDataXtd_GeometryEnum
        Returns the topological attribute s used to define the type of geometric construction for the geometry attribute.

        Parameters
        ----------
        S: TNaming_NamedShape

        Returns
        -------
        TDataXtd_GeometryEnum

        """
        return _TDataXtd.TDataXtd_Geometry_Type(*args)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_Geometry_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_Geometry

# Register TDataXtd_Geometry in _TDataXtd:
_TDataXtd.TDataXtd_Geometry_swigregister(TDataXtd_Geometry)

def TDataXtd_Geometry_Axis(*args) -> "Standard_Boolean":
    r"""
    Returns the axis attribute defined by the label l and the axis g.

    Parameters
    ----------
    L: TDF_Label
    G: gp_Ax1

    Returns
    -------
    bool
    Returns the axis attribute defined by the topological attribute s and the axis g.

    Parameters
    ----------
    S: TNaming_NamedShape
    G: gp_Ax1

    Returns
    -------
    bool

    """
    return _TDataXtd.TDataXtd_Geometry_Axis(*args)

def TDataXtd_Geometry_Circle(*args) -> "Standard_Boolean":
    r"""
    Returns the circle attribute defined by the label l and the circle g.

    Parameters
    ----------
    L: TDF_Label
    G: gp_Circ

    Returns
    -------
    bool
    Returns the circle attribute defined by the topological attribute s and the circle g.

    Parameters
    ----------
    S: TNaming_NamedShape
    G: gp_Circ

    Returns
    -------
    bool

    """
    return _TDataXtd.TDataXtd_Geometry_Circle(*args)

def TDataXtd_Geometry_Cylinder(*args) -> "Standard_Boolean":
    r"""
    Returns the cylinder attribute defined by the label l and the cylinder g.

    Parameters
    ----------
    L: TDF_Label
    G: gp_Cylinder

    Returns
    -------
    bool
    Returns the cylinder attribute defined by the topological attribute s and the cylinder g.

    Parameters
    ----------
    S: TNaming_NamedShape
    G: gp_Cylinder

    Returns
    -------
    bool

    """
    return _TDataXtd.TDataXtd_Geometry_Cylinder(*args)

def TDataXtd_Geometry_Ellipse(*args) -> "Standard_Boolean":
    r"""
    Returns the ellipse attribute defined by the label l and the ellipse g.

    Parameters
    ----------
    L: TDF_Label
    G: gp_Elips

    Returns
    -------
    bool
    Returns the ellipse attribute defined by the topological attribute s and the ellipse g.

    Parameters
    ----------
    S: TNaming_NamedShape
    G: gp_Elips

    Returns
    -------
    bool

    """
    return _TDataXtd.TDataXtd_Geometry_Ellipse(*args)

def TDataXtd_Geometry_GetID(*args) -> "Standard_GUID const &":
    r"""
    Returns the guid for geometry attributes.

    Returns
    -------
    Standard_GUID

    """
    return _TDataXtd.TDataXtd_Geometry_GetID(*args)

def TDataXtd_Geometry_Line(*args) -> "Standard_Boolean":
    r"""
    Returns the line attribute defined by the label l and the line g.

    Parameters
    ----------
    L: TDF_Label
    G: gp_Lin

    Returns
    -------
    bool
    Returns the line attribute defined by the topological attribute s and the line g.

    Parameters
    ----------
    S: TNaming_NamedShape
    G: gp_Lin

    Returns
    -------
    bool

    """
    return _TDataXtd.TDataXtd_Geometry_Line(*args)

def TDataXtd_Geometry_Plane(*args) -> "Standard_Boolean":
    r"""
    Returns the plane attribute defined by the label l and the plane g.

    Parameters
    ----------
    L: TDF_Label
    G: gp_Pln

    Returns
    -------
    bool
    Returns the plane attribute defined by the topological attribute s and the plane g.

    Parameters
    ----------
    S: TNaming_NamedShape
    G: gp_Pln

    Returns
    -------
    bool

    """
    return _TDataXtd.TDataXtd_Geometry_Plane(*args)

def TDataXtd_Geometry_Point(*args) -> "Standard_Boolean":
    r"""
    Returns the point attribute defined by the label l and the point g.

    Parameters
    ----------
    L: TDF_Label
    G: gp_Pnt

    Returns
    -------
    bool
    Returns the point attribute defined by the topological attribute s and the point g.

    Parameters
    ----------
    S: TNaming_NamedShape
    G: gp_Pnt

    Returns
    -------
    bool

    """
    return _TDataXtd.TDataXtd_Geometry_Point(*args)

def TDataXtd_Geometry_Set(*args) -> "opencascade::handle< TDataXtd_Geometry >":
    r"""
    Api class methods ================= finds, or creates, a geometry attribute defined by the label label. the default type of geometry is the value any_geom of the enumeration tdataxtd_geometryenum. to specify another value of this enumeration, use the function settype.

    Parameters
    ----------
    label: TDF_Label

    Returns
    -------
    opencascade::handle<TDataXtd_Geometry>

    """
    return _TDataXtd.TDataXtd_Geometry_Set(*args)

def TDataXtd_Geometry_Type(*args) -> "TDataXtd_GeometryEnum":
    r"""
    Returns the label l used to define the type of geometric construction for the geometry attribute.

    Parameters
    ----------
    L: TDF_Label

    Returns
    -------
    TDataXtd_GeometryEnum
    Returns the topological attribute s used to define the type of geometric construction for the geometry attribute.

    Parameters
    ----------
    S: TNaming_NamedShape

    Returns
    -------
    TDataXtd_GeometryEnum

    """
    return _TDataXtd.TDataXtd_Geometry_Type(*args)

class TDataXtd_Pattern(OCC.Core.TDF.TDF_Attribute):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def ComputeTrsfs(self, *args) -> "void":
        r"""
        Give the transformations.

        Parameters
        ----------
        Trsfs: TDataXtd_Array1OfTrsf

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Pattern_ComputeTrsfs(self, *args)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        No available documentation.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Pattern_GetID(*args)

    def NbTrsfs(self, *args) -> "Standard_Integer":
        r"""
        Give the number of transformation.

        Returns
        -------
        int

        """
        return _TDataXtd.TDataXtd_Pattern_NbTrsfs(self, *args)

    def PatternID(self, *args) -> "Standard_GUID const &":
        r"""
        Returns the id of the attribute.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Pattern_PatternID(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_Pattern_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_Pattern

# Register TDataXtd_Pattern in _TDataXtd:
_TDataXtd.TDataXtd_Pattern_swigregister(TDataXtd_Pattern)

def TDataXtd_Pattern_GetID(*args) -> "Standard_GUID const &":
    r"""
    No available documentation.

    Returns
    -------
    Standard_GUID

    """
    return _TDataXtd.TDataXtd_Pattern_GetID(*args)

class TDataXtd_Placement(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TDataXtd.TDataXtd_Placement_swiginit(self, _TDataXtd.new_TDataXtd_Placement(*args))

    def DumpToString(self) -> "std::string":
        r"""DumpToString(TDataXtd_Placement self) -> std::string"""
        return _TDataXtd.TDataXtd_Placement_DumpToString(self)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        Class methods =============.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Placement_GetID(*args)

    def ID(self, *args) -> "Standard_GUID const &":
        r"""
        No available documentation.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Placement_ID(self, *args)

    @staticmethod
    def Set(*args) -> "opencascade::handle< TDataXtd_Placement >":
        r"""
        Find, or create, an placement attribute. the placement attribute is returned. placement methods =================.

        Parameters
        ----------
        label: TDF_Label

        Returns
        -------
        opencascade::handle<TDataXtd_Placement>

        """
        return _TDataXtd.TDataXtd_Placement_Set(*args)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_Placement_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_Placement

# Register TDataXtd_Placement in _TDataXtd:
_TDataXtd.TDataXtd_Placement_swigregister(TDataXtd_Placement)

def TDataXtd_Placement_GetID(*args) -> "Standard_GUID const &":
    r"""
    Class methods =============.

    Returns
    -------
    Standard_GUID

    """
    return _TDataXtd.TDataXtd_Placement_GetID(*args)

def TDataXtd_Placement_Set(*args) -> "opencascade::handle< TDataXtd_Placement >":
    r"""
    Find, or create, an placement attribute. the placement attribute is returned. placement methods =================.

    Parameters
    ----------
    label: TDF_Label

    Returns
    -------
    opencascade::handle<TDataXtd_Placement>

    """
    return _TDataXtd.TDataXtd_Placement_Set(*args)

class TDataXtd_Plane(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TDataXtd.TDataXtd_Plane_swiginit(self, _TDataXtd.new_TDataXtd_Plane(*args))

    def DumpToString(self) -> "std::string":
        r"""DumpToString(TDataXtd_Plane self) -> std::string"""
        return _TDataXtd.TDataXtd_Plane_DumpToString(self)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        Class methods ============= //! returns the guid for plane attributes.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Plane_GetID(*args)

    def ID(self, *args) -> "Standard_GUID const &":
        r"""
        No available documentation.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Plane_ID(self, *args)

    @staticmethod
    def Set(*args) -> "opencascade::handle< TDataXtd_Plane >":
        r"""
        Finds or creates the plane attribute defined by the label label. warning if you are creating the attribute with this syntax, a planar face should already be associated with label.

        Parameters
        ----------
        label: TDF_Label

        Returns
        -------
        opencascade::handle<TDataXtd_Plane>
        Finds, or creates, a plane attribute and sets <p> as generated the associated namedshape. plane methods =============.

        Parameters
        ----------
        label: TDF_Label
        P: gp_Pln

        Returns
        -------
        opencascade::handle<TDataXtd_Plane>

        """
        return _TDataXtd.TDataXtd_Plane_Set(*args)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_Plane_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_Plane

# Register TDataXtd_Plane in _TDataXtd:
_TDataXtd.TDataXtd_Plane_swigregister(TDataXtd_Plane)

def TDataXtd_Plane_GetID(*args) -> "Standard_GUID const &":
    r"""
    Class methods ============= //! returns the guid for plane attributes.

    Returns
    -------
    Standard_GUID

    """
    return _TDataXtd.TDataXtd_Plane_GetID(*args)

def TDataXtd_Plane_Set(*args) -> "opencascade::handle< TDataXtd_Plane >":
    r"""
    Finds or creates the plane attribute defined by the label label. warning if you are creating the attribute with this syntax, a planar face should already be associated with label.

    Parameters
    ----------
    label: TDF_Label

    Returns
    -------
    opencascade::handle<TDataXtd_Plane>
    Finds, or creates, a plane attribute and sets <p> as generated the associated namedshape. plane methods =============.

    Parameters
    ----------
    label: TDF_Label
    P: gp_Pln

    Returns
    -------
    opencascade::handle<TDataXtd_Plane>

    """
    return _TDataXtd.TDataXtd_Plane_Set(*args)

class TDataXtd_Point(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TDataXtd.TDataXtd_Point_swiginit(self, _TDataXtd.new_TDataXtd_Point(*args))

    def DumpToString(self) -> "std::string":
        r"""DumpToString(TDataXtd_Point self) -> std::string"""
        return _TDataXtd.TDataXtd_Point_DumpToString(self)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        Class methods ============= //! returns the guid for point attributes.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Point_GetID(*args)

    def ID(self, *args) -> "Standard_GUID const &":
        r"""
        No available documentation.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Point_ID(self, *args)

    @staticmethod
    def Set(*args) -> "opencascade::handle< TDataXtd_Point >":
        r"""
        Sets the label label as a point attribute. if no object is found, a point attribute is created.

        Parameters
        ----------
        label: TDF_Label

        Returns
        -------
        opencascade::handle<TDataXtd_Point>
        Sets the label label as a point attribute containing the point p. if no object is found, a point attribute is created. point methods =============.

        Parameters
        ----------
        label: TDF_Label
        P: gp_Pnt

        Returns
        -------
        opencascade::handle<TDataXtd_Point>

        """
        return _TDataXtd.TDataXtd_Point_Set(*args)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_Point_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_Point

# Register TDataXtd_Point in _TDataXtd:
_TDataXtd.TDataXtd_Point_swigregister(TDataXtd_Point)

def TDataXtd_Point_GetID(*args) -> "Standard_GUID const &":
    r"""
    Class methods ============= //! returns the guid for point attributes.

    Returns
    -------
    Standard_GUID

    """
    return _TDataXtd.TDataXtd_Point_GetID(*args)

def TDataXtd_Point_Set(*args) -> "opencascade::handle< TDataXtd_Point >":
    r"""
    Sets the label label as a point attribute. if no object is found, a point attribute is created.

    Parameters
    ----------
    label: TDF_Label

    Returns
    -------
    opencascade::handle<TDataXtd_Point>
    Sets the label label as a point attribute containing the point p. if no object is found, a point attribute is created. point methods =============.

    Parameters
    ----------
    label: TDF_Label
    P: gp_Pnt

    Returns
    -------
    opencascade::handle<TDataXtd_Point>

    """
    return _TDataXtd.TDataXtd_Point_Set(*args)

class TDataXtd_Position(OCC.Core.TDF.TDF_Attribute):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TDataXtd.TDataXtd_Position_swiginit(self, _TDataXtd.new_TDataXtd_Position(*args))

    @staticmethod
    def Get(*args) -> "Standard_Boolean":
        r"""
        Search label <alabel) for the tdataxtd_position attribute and get its position if found returns true.

        Parameters
        ----------
        aLabel: TDF_Label
        aPos: gp_Pnt

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Position_Get(*args)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        Returns the id of the attribute.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Position_GetID(*args)

    def GetPosition(self, *args) -> "gp_Pnt const":
        r"""
        No available documentation.

        Returns
        -------
        gp_Pnt

        """
        return _TDataXtd.TDataXtd_Position_GetPosition(self, *args)

    @staticmethod
    def Set(*args) -> "opencascade::handle< TDataXtd_Position >":
        r"""
        Create if not found the tdataxtd_position attribute set its position to <apos>.

        Parameters
        ----------
        aLabel: TDF_Label
        aPos: gp_Pnt

        Returns
        -------
        None
        Find an existing, or create an empty, position. the position attribute is returned.

        Parameters
        ----------
        aLabel: TDF_Label

        Returns
        -------
        opencascade::handle<TDataXtd_Position>

        """
        return _TDataXtd.TDataXtd_Position_Set(*args)

    def SetPosition(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPos: gp_Pnt

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Position_SetPosition(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_Position_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_Position

# Register TDataXtd_Position in _TDataXtd:
_TDataXtd.TDataXtd_Position_swigregister(TDataXtd_Position)

def TDataXtd_Position_Get(*args) -> "Standard_Boolean":
    r"""
    Search label <alabel) for the tdataxtd_position attribute and get its position if found returns true.

    Parameters
    ----------
    aLabel: TDF_Label
    aPos: gp_Pnt

    Returns
    -------
    bool

    """
    return _TDataXtd.TDataXtd_Position_Get(*args)

def TDataXtd_Position_GetID(*args) -> "Standard_GUID const &":
    r"""
    Returns the id of the attribute.

    Returns
    -------
    Standard_GUID

    """
    return _TDataXtd.TDataXtd_Position_GetID(*args)

def TDataXtd_Position_Set(*args) -> "opencascade::handle< TDataXtd_Position >":
    r"""
    Create if not found the tdataxtd_position attribute set its position to <apos>.

    Parameters
    ----------
    aLabel: TDF_Label
    aPos: gp_Pnt

    Returns
    -------
    None
    Find an existing, or create an empty, position. the position attribute is returned.

    Parameters
    ----------
    aLabel: TDF_Label

    Returns
    -------
    opencascade::handle<TDataXtd_Position>

    """
    return _TDataXtd.TDataXtd_Position_Set(*args)

class TDataXtd_Presentation(OCC.Core.TDF.TDF_Attribute):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _TDataXtd.TDataXtd_Presentation_swiginit(self, _TDataXtd.new_TDataXtd_Presentation(*args))

    def AddSelectionMode(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSelectionMode: int
        theTransaction: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_AddSelectionMode(self, *args)

    def Color(self, *args) -> "Quantity_NameOfColor":
        r"""
        No available documentation.

        Returns
        -------
        Quantity_NameOfColor

        """
        return _TDataXtd.TDataXtd_Presentation_Color(self, *args)

    def GetDriverGUID(self, *args) -> "Standard_GUID":
        r"""
        Returns the guid of the driver managing display of associated ais object.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Presentation_GetDriverGUID(self, *args)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        Returns the id of the attribute.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Presentation_GetID(*args)

    def GetNbSelectionModes(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of selection modes of the attribute. it starts with 1 .. getnbselectionmodes().

        Returns
        -------
        int

        """
        return _TDataXtd.TDataXtd_Presentation_GetNbSelectionModes(self, *args)

    def HasOwnColor(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Presentation_HasOwnColor(self, *args)

    def HasOwnMaterial(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Presentation_HasOwnMaterial(self, *args)

    def HasOwnMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Presentation_HasOwnMode(self, *args)

    def HasOwnSelectionMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Presentation_HasOwnSelectionMode(self, *args)

    def HasOwnTransparency(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Presentation_HasOwnTransparency(self, *args)

    def HasOwnWidth(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Presentation_HasOwnWidth(self, *args)

    def IsDisplayed(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Presentation_IsDisplayed(self, *args)

    def MaterialIndex(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TDataXtd.TDataXtd_Presentation_MaterialIndex(self, *args)

    def Mode(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TDataXtd.TDataXtd_Presentation_Mode(self, *args)

    def SelectionMode(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        index: int,optional
        	default value is 1

        Returns
        -------
        int

        """
        return _TDataXtd.TDataXtd_Presentation_SelectionMode(self, *args)

    @staticmethod
    def Set(*args) -> "opencascade::handle< TDataXtd_Presentation >":
        r"""
        Create if not found the tdataxtd_presentation attribute and set its driver guid.

        Parameters
        ----------
        theLabel: TDF_Label
        theDriverId: Standard_GUID

        Returns
        -------
        opencascade::handle<TDataXtd_Presentation>

        """
        return _TDataXtd.TDataXtd_Presentation_Set(*args)

    def SetColor(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theColor: Quantity_NameOfColor

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_SetColor(self, *args)

    def SetDisplayed(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theIsDisplayed: bool

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_SetDisplayed(self, *args)

    def SetDriverGUID(self, *args) -> "void":
        r"""
        Sets the guid of the driver managing display of associated ais object.

        Parameters
        ----------
        theGUID: Standard_GUID

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_SetDriverGUID(self, *args)

    def SetMaterialIndex(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theMaterialIndex: int

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_SetMaterialIndex(self, *args)

    def SetMode(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theMode: int

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_SetMode(self, *args)

    def SetSelectionMode(self, *args) -> "void":
        r"""
        Sets selection mode. if 'thetransaction' flag is off, modification of the attribute doesn't influence the transaction mechanism (the attribute doesn't participate in undo/redo because of this modification). certainly, if any other data of the attribute is modified (display mode, color, ...), the attribute will be included into undo/redo.

        Parameters
        ----------
        theSelectionMode: int
        theTransaction: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_SetSelectionMode(self, *args)

    def SetTransparency(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: float

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_SetTransparency(self, *args)

    def SetWidth(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theWidth: float

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_SetWidth(self, *args)

    def Transparency(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _TDataXtd.TDataXtd_Presentation_Transparency(self, *args)

    @staticmethod
    def Unset(*args) -> "void":
        r"""
        Remove attribute of this type from the label.

        Parameters
        ----------
        theLabel: TDF_Label

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_Unset(*args)

    def UnsetColor(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_UnsetColor(self, *args)

    def UnsetMaterial(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_UnsetMaterial(self, *args)

    def UnsetMode(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_UnsetMode(self, *args)

    def UnsetSelectionMode(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_UnsetSelectionMode(self, *args)

    def UnsetTransparency(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_UnsetTransparency(self, *args)

    def UnsetWidth(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Presentation_UnsetWidth(self, *args)

    def Width(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _TDataXtd.TDataXtd_Presentation_Width(self, *args)

    @staticmethod
    def getColorNameFromOldEnum(*args) -> "Quantity_NameOfColor":
        r"""
        Convert values of old quantity_nameofcolor to new enumeration for reading old documents after #0030969 (coding rules - refactor quantity_color.cxx color table definition).

        Parameters
        ----------
        theOld: int

        Returns
        -------
        Quantity_NameOfColor

        """
        return _TDataXtd.TDataXtd_Presentation_getColorNameFromOldEnum(*args)

    @staticmethod
    def getOldColorNameFromNewEnum(*args) -> "Standard_Integer":
        r"""
        Convert quantity_nameofcolor to old enumeration value for writing documents in compatible format.

        Parameters
        ----------
        theNew: Quantity_NameOfColor

        Returns
        -------
        int

        """
        return _TDataXtd.TDataXtd_Presentation_getOldColorNameFromNewEnum(*args)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_Presentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_Presentation

# Register TDataXtd_Presentation in _TDataXtd:
_TDataXtd.TDataXtd_Presentation_swigregister(TDataXtd_Presentation)

def TDataXtd_Presentation_GetID(*args) -> "Standard_GUID const &":
    r"""
    Returns the id of the attribute.

    Returns
    -------
    Standard_GUID

    """
    return _TDataXtd.TDataXtd_Presentation_GetID(*args)

def TDataXtd_Presentation_Set(*args) -> "opencascade::handle< TDataXtd_Presentation >":
    r"""
    Create if not found the tdataxtd_presentation attribute and set its driver guid.

    Parameters
    ----------
    theLabel: TDF_Label
    theDriverId: Standard_GUID

    Returns
    -------
    opencascade::handle<TDataXtd_Presentation>

    """
    return _TDataXtd.TDataXtd_Presentation_Set(*args)

def TDataXtd_Presentation_Unset(*args) -> "void":
    r"""
    Remove attribute of this type from the label.

    Parameters
    ----------
    theLabel: TDF_Label

    Returns
    -------
    None

    """
    return _TDataXtd.TDataXtd_Presentation_Unset(*args)

def TDataXtd_Presentation_getColorNameFromOldEnum(*args) -> "Quantity_NameOfColor":
    r"""
    Convert values of old quantity_nameofcolor to new enumeration for reading old documents after #0030969 (coding rules - refactor quantity_color.cxx color table definition).

    Parameters
    ----------
    theOld: int

    Returns
    -------
    Quantity_NameOfColor

    """
    return _TDataXtd.TDataXtd_Presentation_getColorNameFromOldEnum(*args)

def TDataXtd_Presentation_getOldColorNameFromNewEnum(*args) -> "Standard_Integer":
    r"""
    Convert quantity_nameofcolor to old enumeration value for writing documents in compatible format.

    Parameters
    ----------
    theNew: Quantity_NameOfColor

    Returns
    -------
    int

    """
    return _TDataXtd.TDataXtd_Presentation_getOldColorNameFromNewEnum(*args)

class TDataXtd_Shape(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TDataXtd.TDataXtd_Shape_swiginit(self, _TDataXtd.new_TDataXtd_Shape(*args))

    def DumpToString(self) -> "std::string":
        r"""DumpToString(TDataXtd_Shape self) -> std::string"""
        return _TDataXtd.TDataXtd_Shape_DumpToString(self)

    @staticmethod
    def Find(*args) -> "Standard_Boolean":
        r"""
        Class methods ============= try to retrieve a shape attribute at <current> label or in fathers label of <current>. returns true if found and set <s>.

        Parameters
        ----------
        current: TDF_Label
        S: TDataXtd_Shape

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Shape_Find(*args)

    @staticmethod
    def Get(*args) -> "TopoDS_Shape":
        r"""
        The shape from associated namedshape attribute is returned.

        Parameters
        ----------
        label: TDF_Label

        Returns
        -------
        TopoDS_Shape

        """
        return _TDataXtd.TDataXtd_Shape_Get(*args)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        Shape methods ============.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Shape_GetID(*args)

    def ID(self, *args) -> "Standard_GUID const &":
        r"""
        No available documentation.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Shape_ID(self, *args)

    @staticmethod
    def New(*args) -> "opencascade::handle< TDataXtd_Shape >":
        r"""
        Find, or create, a shape attribute. the shape attribute is returned. raises if <label> has attribute.

        Parameters
        ----------
        label: TDF_Label

        Returns
        -------
        opencascade::handle<TDataXtd_Shape>

        """
        return _TDataXtd.TDataXtd_Shape_New(*args)

    def References(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        DS: TDF_DataSet

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Shape_References(self, *args)

    @staticmethod
    def Set(*args) -> "opencascade::handle< TDataXtd_Shape >":
        r"""
        Create or update associated namedshape attribute. the shape attribute is returned.

        Parameters
        ----------
        label: TDF_Label
        shape: TopoDS_Shape

        Returns
        -------
        opencascade::handle<TDataXtd_Shape>

        """
        return _TDataXtd.TDataXtd_Shape_Set(*args)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_Shape_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_Shape

# Register TDataXtd_Shape in _TDataXtd:
_TDataXtd.TDataXtd_Shape_swigregister(TDataXtd_Shape)

def TDataXtd_Shape_Find(*args) -> "Standard_Boolean":
    r"""
    Class methods ============= try to retrieve a shape attribute at <current> label or in fathers label of <current>. returns true if found and set <s>.

    Parameters
    ----------
    current: TDF_Label
    S: TDataXtd_Shape

    Returns
    -------
    bool

    """
    return _TDataXtd.TDataXtd_Shape_Find(*args)

def TDataXtd_Shape_Get(*args) -> "TopoDS_Shape":
    r"""
    The shape from associated namedshape attribute is returned.

    Parameters
    ----------
    label: TDF_Label

    Returns
    -------
    TopoDS_Shape

    """
    return _TDataXtd.TDataXtd_Shape_Get(*args)

def TDataXtd_Shape_GetID(*args) -> "Standard_GUID const &":
    r"""
    Shape methods ============.

    Returns
    -------
    Standard_GUID

    """
    return _TDataXtd.TDataXtd_Shape_GetID(*args)

def TDataXtd_Shape_New(*args) -> "opencascade::handle< TDataXtd_Shape >":
    r"""
    Find, or create, a shape attribute. the shape attribute is returned. raises if <label> has attribute.

    Parameters
    ----------
    label: TDF_Label

    Returns
    -------
    opencascade::handle<TDataXtd_Shape>

    """
    return _TDataXtd.TDataXtd_Shape_New(*args)

def TDataXtd_Shape_Set(*args) -> "opencascade::handle< TDataXtd_Shape >":
    r"""
    Create or update associated namedshape attribute. the shape attribute is returned.

    Parameters
    ----------
    label: TDF_Label
    shape: TopoDS_Shape

    Returns
    -------
    opencascade::handle<TDataXtd_Shape>

    """
    return _TDataXtd.TDataXtd_Shape_Set(*args)

class TDataXtd_Triangulation(OCC.Core.TDF.TDF_Attribute):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        A constructor. don't use it directly, use please the static method set(), which returns the attribute attached to a label.

        Returns
        -------
        None

        """
        _TDataXtd.TDataXtd_Triangulation_swiginit(self, _TDataXtd.new_TDataXtd_Triangulation(*args))

    def Deflection(self, *args) -> "void":
        r"""
        Returns the deflection of this triangulation.

        Returns
        -------
        float
        Sets the deflection of this triangulation to thedeflection. see more on deflection in polygon2d.

        Parameters
        ----------
        theDeflection: float

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Triangulation_Deflection(self, *args)

    def DumpToString(self) -> "std::string":
        r"""DumpToString(TDataXtd_Triangulation self) -> std::string"""
        return _TDataXtd.TDataXtd_Triangulation_DumpToString(self)

    def Get(self, *args) -> "opencascade::handle< Poly_Triangulation > const &":
        r"""
        Returns the underlying triangulation.

        Returns
        -------
        opencascade::handle<Poly_Triangulation>

        """
        return _TDataXtd.TDataXtd_Triangulation_Get(self, *args)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        Returns the id of the triangulation attribute.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_Triangulation_GetID(*args)

    def HasNormals(self, *args) -> "Standard_Boolean":
        r"""
        Returns standard_true if nodal normals are defined.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Triangulation_HasNormals(self, *args)

    def HasUVNodes(self, *args) -> "Standard_Boolean":
        r"""
        Returns standard_true if 2d nodes are associated with 3d nodes for this triangulation.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_Triangulation_HasUVNodes(self, *args)

    def NbNodes(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of nodes for this triangulation.

        Returns
        -------
        int

        """
        return _TDataXtd.TDataXtd_Triangulation_NbNodes(self, *args)

    def NbTriangles(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of triangles for this triangulation.

        Returns
        -------
        int

        """
        return _TDataXtd.TDataXtd_Triangulation_NbTriangles(self, *args)

    def Node(self, *args) -> "gp_Pnt const":
        r"""
        Returns node at the given index. raises standard_outofrange exception if theindex is less than 1 or greater than nbnodes.

        Parameters
        ----------
        theIndex: int

        Returns
        -------
        gp_Pnt

        """
        return _TDataXtd.TDataXtd_Triangulation_Node(self, *args)

    def Normal(self, *args) -> "gp_Dir const":
        r"""
        Returns normal at the given index. raises standard_outofrange exception.

        Parameters
        ----------
        theIndex: int

        Returns
        -------
        gp_Dir

        """
        return _TDataXtd.TDataXtd_Triangulation_Normal(self, *args)

    def RemoveUVNodes(self, *args) -> "void":
        r"""
        Deallocates the uv nodes.

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Triangulation_RemoveUVNodes(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Finds or creates a triangulation attribute.

        Parameters
        ----------
        theLabel: TDF_Label

        Returns
        -------
        opencascade::handle<TDataXtd_Triangulation>
        Finds or creates a triangulation attribute. initializes the attribute by a poly_triangulation object.

        Parameters
        ----------
        theLabel: TDF_Label
        theTriangulation: Poly_Triangulation

        Returns
        -------
        opencascade::handle<TDataXtd_Triangulation>
        Sets the triangulation.

        Parameters
        ----------
        theTriangulation: Poly_Triangulation

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Triangulation_Set(self, *args)

    def SetNode(self, *args) -> "void":
        r"""
        The method differs from poly_triangulation! sets a node at the given index. raises standard_outofrange exception if theindex is less than 1 or greater than nbnodes.

        Parameters
        ----------
        theIndex: int
        theNode: gp_Pnt

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Triangulation_SetNode(self, *args)

    def SetNormal(self, *args) -> "void":
        r"""
        Changes normal at the given index. raises standard_outofrange exception.

        Parameters
        ----------
        theIndex: int
        theNormal: gp_Dir

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Triangulation_SetNormal(self, *args)

    def SetNormals(self, *args) -> "void":
        r"""
        Sets the table of node normals. raises exception if length of thenormals != 3 * nbnodes.

        Parameters
        ----------
        theNormals: TShort_HArray1OfShortReal

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Triangulation_SetNormals(self, *args)

    def SetTriangle(self, *args) -> "void":
        r"""
        The method differs from poly_triangulation! sets a triangle at the given index. raises standard_outofrange exception if theindex is less than 1 or greater than nbtriangles.

        Parameters
        ----------
        theIndex: int
        theTriangle: Poly_Triangle

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Triangulation_SetTriangle(self, *args)

    def SetUVNode(self, *args) -> "void":
        r"""
        The method differs from poly_triangulation! sets a uvnode at the given index. raises standard_outofrange exception if theindex is less than 1 or greater than nbnodes.

        Parameters
        ----------
        theIndex: int
        theUVNode: gp_Pnt2d

        Returns
        -------
        None

        """
        return _TDataXtd.TDataXtd_Triangulation_SetUVNode(self, *args)

    def Triangle(self, *args) -> "Poly_Triangle const &":
        r"""
        Returns triangle at the given index. raises standard_outofrange exception if theindex is less than 1 or greater than nbtriangles.

        Parameters
        ----------
        theIndex: int

        Returns
        -------
        Poly_Triangle

        """
        return _TDataXtd.TDataXtd_Triangulation_Triangle(self, *args)

    def UVNode(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns uvnode at the given index. raises standard_outofrange exception if theindex is less than 1 or greater than nbnodes.

        Parameters
        ----------
        theIndex: int

        Returns
        -------
        gp_Pnt2d

        """
        return _TDataXtd.TDataXtd_Triangulation_UVNode(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_Triangulation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_Triangulation

# Register TDataXtd_Triangulation in _TDataXtd:
_TDataXtd.TDataXtd_Triangulation_swigregister(TDataXtd_Triangulation)

def TDataXtd_Triangulation_GetID(*args) -> "Standard_GUID const &":
    r"""
    Returns the id of the triangulation attribute.

    Returns
    -------
    Standard_GUID

    """
    return _TDataXtd.TDataXtd_Triangulation_GetID(*args)

class TDataXtd_PatternStd(TDataXtd_Pattern):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TDataXtd.TDataXtd_PatternStd_swiginit(self, _TDataXtd.new_TDataXtd_PatternStd(*args))

    def Axis1(self, *args) -> "opencascade::handle< TNaming_NamedShape >":
        r"""
        No available documentation.

        Parameters
        ----------
        Axis1: TNaming_NamedShape

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        opencascade::handle<TNaming_NamedShape>

        """
        return _TDataXtd.TDataXtd_PatternStd_Axis1(self, *args)

    def Axis1Reversed(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        Axis1Reversed: bool

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_PatternStd_Axis1Reversed(self, *args)

    def Axis2(self, *args) -> "opencascade::handle< TNaming_NamedShape >":
        r"""
        No available documentation.

        Parameters
        ----------
        Axis2: TNaming_NamedShape

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        opencascade::handle<TNaming_NamedShape>

        """
        return _TDataXtd.TDataXtd_PatternStd_Axis2(self, *args)

    def Axis2Reversed(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        Axis2Reversed: bool

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        bool

        """
        return _TDataXtd.TDataXtd_PatternStd_Axis2Reversed(self, *args)

    def DumpToString(self) -> "std::string":
        r"""DumpToString(TDataXtd_PatternStd self) -> std::string"""
        return _TDataXtd.TDataXtd_PatternStd_DumpToString(self)

    @staticmethod
    def GetPatternID(*args) -> "Standard_GUID const &":
        r"""
        No available documentation.

        Returns
        -------
        Standard_GUID

        """
        return _TDataXtd.TDataXtd_PatternStd_GetPatternID(*args)

    def Mirror(self, *args) -> "opencascade::handle< TNaming_NamedShape >":
        r"""
        No available documentation.

        Parameters
        ----------
        plane: TNaming_NamedShape

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        opencascade::handle<TNaming_NamedShape>

        """
        return _TDataXtd.TDataXtd_PatternStd_Mirror(self, *args)

    def NbInstances1(self, *args) -> "opencascade::handle< TDataStd_Integer >":
        r"""
        No available documentation.

        Parameters
        ----------
        NbInstances1: TDataStd_Integer

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        opencascade::handle<TDataStd_Integer>

        """
        return _TDataXtd.TDataXtd_PatternStd_NbInstances1(self, *args)

    def NbInstances2(self, *args) -> "opencascade::handle< TDataStd_Integer >":
        r"""
        No available documentation.

        Parameters
        ----------
        NbInstances2: TDataStd_Integer

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        opencascade::handle<TDataStd_Integer>

        """
        return _TDataXtd.TDataXtd_PatternStd_NbInstances2(self, *args)

    @staticmethod
    def Set(*args) -> "opencascade::handle< TDataXtd_PatternStd >":
        r"""
        Find, or create, a patternstd attribute.

        Parameters
        ----------
        label: TDF_Label

        Returns
        -------
        opencascade::handle<TDataXtd_PatternStd>

        """
        return _TDataXtd.TDataXtd_PatternStd_Set(*args)

    def Signature(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        signature: int

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        int

        """
        return _TDataXtd.TDataXtd_PatternStd_Signature(self, *args)

    def Value1(self, *args) -> "opencascade::handle< TDataStd_Real >":
        r"""
        No available documentation.

        Parameters
        ----------
        value: TDataStd_Real

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        opencascade::handle<TDataStd_Real>

        """
        return _TDataXtd.TDataXtd_PatternStd_Value1(self, *args)

    def Value2(self, *args) -> "opencascade::handle< TDataStd_Real >":
        r"""
        No available documentation.

        Parameters
        ----------
        value: TDataStd_Real

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        opencascade::handle<TDataStd_Real>

        """
        return _TDataXtd.TDataXtd_PatternStd_Value2(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_PatternStd_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_PatternStd

# Register TDataXtd_PatternStd in _TDataXtd:
_TDataXtd.TDataXtd_PatternStd_swigregister(TDataXtd_PatternStd)

def TDataXtd_PatternStd_GetPatternID(*args) -> "Standard_GUID const &":
    r"""
    No available documentation.

    Returns
    -------
    Standard_GUID

    """
    return _TDataXtd.TDataXtd_PatternStd_GetPatternID(*args)

def TDataXtd_PatternStd_Set(*args) -> "opencascade::handle< TDataXtd_PatternStd >":
    r"""
    Find, or create, a patternstd attribute.

    Parameters
    ----------
    label: TDF_Label

    Returns
    -------
    opencascade::handle<TDataXtd_PatternStd>

    """
    return _TDataXtd.TDataXtd_PatternStd_Set(*args)

class TDataXtd_HArray1OfTrsf(TDataXtd_Array1OfTrsf, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TDataXtd.TDataXtd_HArray1OfTrsf_swiginit(self, _TDataXtd.new_TDataXtd_HArray1OfTrsf(*args))

    def Array1(self) -> "TDataXtd_Array1OfTrsf const &":
        return _TDataXtd.TDataXtd_HArray1OfTrsf_Array1(self)

    def ChangeArray1(self) -> "TDataXtd_Array1OfTrsf &":
        return _TDataXtd.TDataXtd_HArray1OfTrsf_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_TDataXtd_HArray1OfTrsf_DownCast(t)

    __swig_destroy__ = _TDataXtd.delete_TDataXtd_HArray1OfTrsf

# Register TDataXtd_HArray1OfTrsf in _TDataXtd:
_TDataXtd.TDataXtd_HArray1OfTrsf_swigregister(TDataXtd_HArray1OfTrsf)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.STEPConstruct import *
from OCC.Core.XSControl import *
from OCC.Core.StepData import *
from OCC.Core.StepBasic import *
from OCC.Core.StepFEA import *
from OCC.Core.StepRepr import *
from OCC.Core.StepElement import *
from OCC.Core.StepShape import *


class StepAP209_Construct(STEPConstruct_Tool):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, WS: XSControl_WorkSession) -> None: ...
	def CreateAP203Structure(self) -> StepData_StepModel: ...
	def CreateAdding203Entities(self, PD: StepBasic_ProductDefinition, aModel: StepData_StepModel) -> bool: ...
	def CreateAddingEntities(self, AnaPD: StepBasic_ProductDefinition) -> bool: ...
	def CreateAnalysStructure(self, Prod: StepBasic_Product) -> bool: ...
	def CreateFeaStructure(self, Prod: StepBasic_Product) -> bool: ...
	@overload
	def FeaModel(self, Prod: StepBasic_Product) -> StepFEA_FeaModel: ...
	@overload
	def FeaModel(self, PDF: StepBasic_ProductDefinitionFormation) -> StepFEA_FeaModel: ...
	@overload
	def FeaModel(self, PDS: StepRepr_ProductDefinitionShape) -> StepFEA_FeaModel: ...
	@overload
	def FeaModel(self, PD: StepBasic_ProductDefinition) -> StepFEA_FeaModel: ...
	def GetCurElemSection(self, ElemRepr: StepFEA_Curve3dElementRepresentation) -> StepElement_HSequenceOfCurveElementSectionDefinition: ...
	def GetElemGeomRelat(self) -> StepFEA_HSequenceOfElementGeometricRelationship: ...
	def GetElementMaterial(self) -> StepElement_HSequenceOfElementMaterial: ...
	def GetElements1D(self, theFeaModel: StepFEA_FeaModel) -> StepFEA_HSequenceOfElementRepresentation: ...
	def GetElements2D(self, theFEAModel: StepFEA_FeaModel) -> StepFEA_HSequenceOfElementRepresentation: ...
	def GetElements3D(self, theFEAModel: StepFEA_FeaModel) -> StepFEA_HSequenceOfElementRepresentation: ...
	def GetFeaAxis2Placement3d(self, theFeaModel: StepFEA_FeaModel) -> StepFEA_FeaAxis2Placement3d: ...
	def GetShReprForElem(self, ElemRepr: StepFEA_ElementRepresentation) -> StepShape_ShapeRepresentation: ...
	@overload
	def IdealShape(self, Prod: StepBasic_Product) -> StepShape_ShapeRepresentation: ...
	@overload
	def IdealShape(self, PDF: StepBasic_ProductDefinitionFormation) -> StepShape_ShapeRepresentation: ...
	@overload
	def IdealShape(self, PD: StepBasic_ProductDefinition) -> StepShape_ShapeRepresentation: ...
	@overload
	def IdealShape(self, PDS: StepRepr_ProductDefinitionShape) -> StepShape_ShapeRepresentation: ...
	def Init(self, WS: XSControl_WorkSession) -> bool: ...
	def IsAnalys(self, PD: StepBasic_ProductDefinitionFormation) -> bool: ...
	def IsDesing(self, PD: StepBasic_ProductDefinitionFormation) -> bool: ...
	@overload
	def NominShape(self, Prod: StepBasic_Product) -> StepShape_ShapeRepresentation: ...
	@overload
	def NominShape(self, PDF: StepBasic_ProductDefinitionFormation) -> StepShape_ShapeRepresentation: ...
	def ReplaceCcDesingToApplied(self) -> bool: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColStd import *
from OCC.Core.Message import *
from OCC.Core.TDF import *
from OCC.Core.BinObjMgt import *
from OCC.Core.TCollection import *

#the following typedef cannot be wrapped as is
BinMDF_DoubleMapIteratorOfTypeIdMap = NewType('BinMDF_DoubleMapIteratorOfTypeIdMap', Any)
BinMDF_StringIdMap = NewType('BinMDF_StringIdMap', TColStd_DataMapOfAsciiStringInteger)
#the following typedef cannot be wrapped as is
BinMDF_TypeIdMap = NewType('BinMDF_TypeIdMap', Any)

class binmdf:
	@staticmethod
	def AddDrivers(aDriverTable: BinMDF_ADriverTable, aMsgDrv: Message_Messenger) -> None: ...

class BinMDF_ADriver(Standard_Transient):
	def MessageDriver(self) -> Message_Messenger: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, aSource: BinObjMgt_Persistent, aTarget: TDF_Attribute, aRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, aSource: TDF_Attribute, aTarget: BinObjMgt_Persistent, aRelocTable: BinObjMgt_SRelocationTable) -> None: ...
	def SourceType(self) -> Standard_Type: ...
	def TypeName(self) -> TCollection_AsciiString: ...

class BinMDF_ADriverTable(Standard_Transient):
	def __init__(self) -> None: ...
	@overload
	def AddDerivedDriver(self, theInstance: TDF_Attribute) -> None: ...
	@overload
	def AddDerivedDriver(self, theDerivedType: str) -> Standard_Type: ...
	def AddDriver(self, theDriver: BinMDF_ADriver) -> None: ...
	@overload
	def AssignIds(self, theTypes: TColStd_IndexedMapOfTransient) -> None: ...
	@overload
	def AssignIds(self, theTypeNames: TColStd_SequenceOfAsciiString) -> None: ...
	@overload
	def GetDriver(self, theType: Standard_Type, theDriver: BinMDF_ADriver) -> int: ...
	@overload
	def GetDriver(self, theTypeId: int) -> BinMDF_ADriver: ...

class BinMDF_DerivedDriver(BinMDF_ADriver):
	def __init__(self, theDerivative: TDF_Attribute, theBaseDriver: BinMDF_ADriver) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: BinObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: BinObjMgt_Persistent, theRelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDF_ReferenceDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

class BinMDF_TagSourceDriver(BinMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: BinObjMgt_Persistent, Target: TDF_Attribute, RelocTable: BinObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: BinObjMgt_Persistent, RelocTable: BinObjMgt_SRelocationTable) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

binmdf_AddDrivers = binmdf.AddDrivers
